@@ -22,12 +22,11 @@
 @requires: U{simplejson<http://cheeseshop.python.org/pypi/simplejson>} package.
 @requires: U{PyXML<http://pyxml.sourceforge.net/>} package.
 @requires: U{RDFLib<http://rdflib.net>} package.
-
-
 """
 
 import urllib, urllib2
 import re
+from SPARQLWrapper import __agent__
 from sparqlexceptions import QueryBadFormed, EndPointNotFound
 
 #  Possible output format keys...
@@ -92,7 +91,7 @@ class SPARQLWrapper :
 				(?P<prefixes>(\s*PREFIX\s*.*[:]\s*[<].*[>])\s*)*
 				(?P<queryType>(CONSTRUCT|SELECT|ASK|DESCRIBE))
 	""", re.VERBOSE | re.IGNORECASE)
-	def __init__(self,baseURI,returnFormat=XML,defaultGraph=None) :
+	def __init__(self,baseURI,returnFormat=XML,defaultGraph=None,agent=__agent__) :
 		"""
 		Class encapsulating a full SPARQL call.
 		@param baseURI: string of the SPARQL endpoint's URI
@@ -112,6 +111,7 @@ class SPARQLWrapper :
 		@type defaultGraph: string
 		"""
 		self.baseURI     = baseURI
+		self.agent       = agent
 		self._querytext  = []
 		self._defaultGraph = defaultGraph
 		if defaultGraph : self._querytext.append(("default-graph-uri",defaultGraph))
@@ -196,8 +196,11 @@ class SPARQLWrapper :
 			@type query: string
 			@rtype: string
 		"""
-		r_queryType = self.pattern.search(query).group("queryType").upper()
-
+		try:
+			r_queryType = self.pattern.search(query).group("queryType").upper()
+		except AttributeError:
+			r_queryType = None
+	
 		if r_queryType in _allowedQueryTypes :
 			return r_queryType
 		else :
@@ -254,8 +257,9 @@ class SPARQLWrapper :
 		if self.method == POST :
 			# by POST
 			request = urllib2.Request(self.baseURI)
-			request.add_header("Content-Type","application/x-www-form-urlencoded")
-			request.add_header("Accept",acceptHeader)
+			request.add_header("Content-Type", "application/x-www-form-urlencoded")
+			request.add_header("'User-Agent", self.agent)
+			request.add_header("Accept", acceptHeader)
 			values = { "query" : self.queryString }
 			data = urllib.urlencode(values)
 			request.add_data(data)
